[−][src]Macro sp_tracing::enter_span
macro_rules! enter_span { ( $name:expr ) => { ... }; }
Enter a span.
The span will be valid, until the scope is left.
Example
sp_tracing::enter_span!("test-span");
macro_rules! enter_span { ( $name:expr ) => { ... }; }
Enter a span.
The span will be valid, until the scope is left.
sp_tracing::enter_span!("test-span");